<div align="center">
<img src="https://raw.githubusercontent.com/snbck/stuoe.github.io/master/static/Stuoe.png" width="300" height="300">

</div>


## Stuoe是轻量的论坛软件

* 前端使用[MDUI](https://mdui.org/)，这是一个基于 [Material Design](https://material.io/design/) 的前端框架，CSS和JS文件压缩后仅有40KB大小

* 基于[Python Flask](https://github.com/pallets/flask)，运行迅速。数据库使用[Sqlite3](https://www.sqlite.org/index.html)，不用配置数据库环境，意味着可以在任何安装Python的服务器上轻松安装并运行

* 每当回复或将帖子设为星标后，将被归纳到帖子的讨论组，如图群组。当讨论发生了新的事务，所有人都会接到[通知](https://baike.baidu.com/item/%E9%80%9A%E7%9F%A5/5957034)。讨论无阻碍

* 使用[Simditor](https://simditor.tower.im/)富文本编辑器，胜任各种排版，使用[Base64](https://www.base64decode.org/)存储图片可以减少[Requests](https://github.com/request/request)数量，减轻服务器负载，加快界面渲染速度

## 文档
文档在 [https://docs.stuoe.cn](https://docs.stuoe.cn)

github仓库 [https://github.com/snbck/stuoe-docs](https://github.com/snbck/stuoe-docs)


## 赞助
欢迎在爱发电赞助我，开发和服务器费用都是自费，任何赞助都能让我更好的开发！

在[爱发电](http://afdian.net/)赞助我  [@stuoe](http://afdian.net/@stuoe)


## 链接

* 官网:  [https://stuoe.cn](https://stuoe.cn)
* 版本 : [https://pypi.org/project/stuoe](https://pypi.org/project/stuoe)
* 论坛 : [http://discuss.stuoe.cn/](http://discuss.stuoe.cn/)
* 文档 : [https://docs.stuoe.cn/](https://docs.stuoe.cn/)

## 协议
使用[Apache License](http://www.apache.org/licenses/)，请关注[License](https://github.com/stuoe/stuoe/blob/master/LICENSE)


